@@ -4,12 +4,12 @@ Main interface for sagemaker-runtime service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_sagemaker_runtime.type_defs import InvokeEndpointOutputTypeDef
+    from mypy_boto3_sagemaker_runtime.type_defs import ResponseMetadata
 
-    data: InvokeEndpointOutputTypeDef = {...}
+    data: ResponseMetadata = {...}
     ```
 """
-import sys
+from typing import Any, Dict
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -17,14 +17,30 @@ else:
     from typing_extensions import TypedDict
 
 
-__all__ = ("InvokeEndpointOutputTypeDef",)
+__all__ = ("ResponseMetadata", "InvokeEndpointOutputTypeDef")
+
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
 
 _RequiredInvokeEndpointOutputTypeDef = TypedDict(
     "_RequiredInvokeEndpointOutputTypeDef", {"Body": bytes}
 )
 _OptionalInvokeEndpointOutputTypeDef = TypedDict(
     "_OptionalInvokeEndpointOutputTypeDef",
-    {"ContentType": str, "InvokedProductionVariant": str, "CustomAttributes": str},
+    {
+        "ContentType": str,
+        "InvokedProductionVariant": str,
+        "CustomAttributes": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
